@@ -1,9 +1,10 @@
 package DBIx::Class::Helper::ResultSet::AutoRemoveColumns;
+$DBIx::Class::Helper::ResultSet::AutoRemoveColumns::VERSION = '2.023007';
+use strict;
+use warnings;
 
 # ABSTRACT: Automatically remove columns from a ResultSet
 
-our $VERSION = '2.019002'; # VERSION
-
 use parent 'DBIx::Class::Helper::ResultSet::RemoveColumns', 'DBIx::Class';
 
 __PACKAGE__->mk_group_accessors(inherited => '_fetchable_columns');
@@ -58,16 +59,10 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 DBIx::Class::Helper::ResultSet::AutoRemoveColumns - Automatically remove columns from a ResultSet
 
-=head1 VERSION
-
-version 2.019002
-
 =head1 SYNOPSIS
 
  package MySchema::Result::Bar;
